/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

@import url(resource:/res/html.css);
@import url(chrome://global/content/xul.css);
@import url(resource:/res/quirk.css);

@namespace parsererror url(http://www.mozilla.org/newlayout/xml/parsererror.xml);

/* magic -- some of these rules are important to keep pages from overriding
            them
*/

/* Tables */

*|*:-moz-table {
  display: table !important;
  -moz-box-sizing: border-box; /* XXX do we really want this? */
}

*|*:-moz-table-outer {
  display: table !important;
  margin: 0;
  padding: 0;
  width: 0;
  height: 0;
  float: inherit;
  clear: inherit;
  position: inherit;
  top: inherit;
  right: inherit;
  bottom: inherit;
  left: inherit;
  z-index: inherit;
  clip: inherit;
  /* background and border should be inherited so that computed style
   * (which uses the outer frame) will get the right values for these
   * properties.  Since the outer frame does not paint, inheriting
   * these is OK.
   */
  background: inherit;
  border: inherit;
  -moz-opacity: inherit;
  page-break-before: inherit;
  page-break-after: inherit;
}

*|*:-moz-table-row {
  display: table-row !important;
}

/* The :-moz-table-column pseudo-element is for extra columns at the end 
   of a table. */
*|*:-moz-table-column {
  display: table-column !important;
}

*|*:-moz-table-column-group {
  display: table-column-group !important;
}
 
*|*:-moz-table-row-group {
  display: table-row-group !important;
}

*|*:-moz-table-cell {
  display: table-cell !important;
  padding: 1px;
  white-space: inherit;
}

/* Lists */

*|*:-moz-list-bullet, *|*:-moz-list-number {
  display: inline;
  vertical-align: baseline;
  margin-right: 8px;
}

/* Links */

*|*:-moz-any-link {
  cursor: pointer;
  -moz-user-focus: normal;
}

*|*:-moz-any-link:active {
  color: red;
}

*|*:-moz-any-link:focus {
  -moz-outline: 1px dotted invert;
}

/* Miscellaneous */

*|*:-moz-anonymous-block, *|*:-moz-cell-content {
  display: block !important;
}

*|*:-moz-viewport, *|*:-moz-viewport-scroll, *|*:-moz-canvas {
  display: block !important;
  background-color: inherit;
}

*|*:-moz-scrolled-content { 
  /* e.g., text inputs, select boxes */
  background: inherit;
  padding: inherit;
  display: inherit;
  -moz-box-orient: inherit;
}

*|*:-moz-page, *|*:-moz-page-sequence {
  display: block !important;
  background: transparent;
}

*|*:-moz-pagecontent {
  display: block !important;
}

*|*:-moz-pagebreak {
  display: -moz-page-break !important;
}

*|*:-moz-anonymous-positioned-block {
  display: block !important;
  position: relative;
  top: inherit; 
  left: inherit;
  bottom: inherit;
  right: inherit;
  z-index: inherit;
  clip: inherit;
  -moz-opacity: inherit;
}

*|*:-moz-gc-wrapper-block {
  display: block !important;
}

/* Printing */

@media print {

  * {
    cursor: default !important;
  }

  *|*:-moz-viewport, *|*:-moz-viewport-scroll, *|*:-moz-canvas {
    background-color: #737373 !important;
  }

  *|*:-moz-any-link {
    -moz-user-focus: none !important;
  }

}

/* XML parse error reporting */

parsererror|parsererror {
  display: block;
  font-family: sans-serif;
  font-weight: bold;
  white-space: pre;
  margin: 1em;
  padding: 1em;
  border-width: thin;
  border-style: inset;
  border-color: red;
  font-size: 14pt;
  background-color: lightyellow;
}

parsererror|sourcetext {
  display: block;
  white-space: pre;
  font-family: Courier;
  margin-top: 2em;
  margin-bottom: 1em;
  color: red;
  font-weight: bold;
  font-size: 12pt;
}
